@@ -3,8 +3,12 @@
 * (C) 1999-2007 The Botan Project                *
 *************************************************/
 
-#ifndef BOTAN_EXT_ASM_MACROS_H__
-#define BOTAN_EXT_ASM_MACROS_H__
+#ifndef BOTAN_EXT_AMD64_ASM_MACROS_H__
+#define BOTAN_EXT_AMD64_ASM_MACROS_H__
+
+#ifdef __ELF__
+.section .note.GNU-stack,"",%progbits
+#endif
 
 /*************************************************
 * General/Global Macros                          *
