@@ -1,6 +1,6 @@
 /*************************************************
 * OpenSSL Engine Header File                     *
-* (C) 1999-2005 The Botan Project                *
+* (C) 1999-2007 The Botan Project                *
 *************************************************/
 
 #ifndef BOTAN_EXT_ENGINE_OPENSSL_H__
@@ -26,7 +26,9 @@ class OpenSSL_Engine : public Engine
       ELG_Operation* elg_op(const DL_Group&, const BigInt&,
                             const BigInt&) const;
       DH_Operation* dh_op(const DL_Group&, const BigInt&) const;
-      ModularReducer* reducer(const BigInt&, bool) const;
+
+      Modular_Exponentiator* mod_exp(const BigInt&,
+                                     Power_Mod::Usage_Hints) const;
    private:
       BlockCipher* find_block_cipher(const std::string&) const;
       StreamCipher* find_stream_cipher(const std::string&) const;
